==> dotclear-1.2.zip: dotclear/l10n/fr-utf8/install.lang.php <==
<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
#


#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Installation'] = 'Installation';
$GLOBALS['__l10n']['Welcome on DotClear installation'] = 'Bienvenue sur l\'installeur de DotClear';
$GLOBALS['__l10n']['You are about to install DotClear. Please choose your language and encoding.'] = 'Vous allez installer DotClear. Choisissez votre langue et l\'encodage.';
$GLOBALS['__l10n']['Go'] = 'Continuer';
$GLOBALS['__l10n']['Next step'] = 'Étape suivante';
$GLOBALS['__l10n']['DotClear is still installed.'] = 'DotClear est déjà installé.';
$GLOBALS['__l10n']['Upgrade'] = 'Mettre à jour';
$GLOBALS['__l10n']['Note: You must accept session cookies to use this installer.'] = 'Note : Vous devez accepter les cookies de session pour utiliser cet installeur';
$GLOBALS['__l10n']['Checking your configuration'] = 'Vérification de votre configuration';
$GLOBALS['__l10n']['PHP version and modules'] = 'Version de PHP et modules';
$GLOBALS['__l10n']['PHP version is %s.'] = 'La version de PHP est %s';
$GLOBALS['__l10n']['PHP version is %s. Version 4.1 or better is required.'] = 'La version de PHP est %s. La version 4.1 ou plus est nécessaire.';
$GLOBALS['__l10n']['%s module is present.'] = 'Le module %s est présent.';
$GLOBALS['__l10n']['%s module is not present.'] = 'Le module %s est absent.';
$GLOBALS['__l10n']['Files permissions'] = 'Permissions sur les fichiers';
$GLOBALS['__l10n']['%s is writable.'] = '%s est accessible en écriture.';
$GLOBALS['__l10n']['%s is not writable. Please change its permissions to install.'] = '%s n\'est pas accessible en écriture. Changez ses permission pour installer.';
$GLOBALS['__l10n']['DotClear cannot be installed.'] = 'DotClear ne peut pas être installé.';
$GLOBALS['__l10n']['Your PHP configuration is not valid. Please contact your Web host to solve this problem.'] = 'Votre configuration n\'est pas suffisante. Contactez votre hébergeur pour résoudre ce problème.';
$GLOBALS['__l10n']['Some files or directories are not writable. Please change their permissions to install DotClear.'] = 'Des fichiers ou répertoires ne sont pas accessibles en écritures. Changez leurs permissions pour installer DotClear.';
$GLOBALS['__l10n']['DotClear can be installed on your site.'] = 'DotClear peut être installé sur votre site.';
$GLOBALS['__l10n']['Database parameters'] = 'Paramètres de la base de données';
$GLOBALS['__l10n']['Invalid tables prefix. It can contain only letters or "_".'] = 'Préfixe des tables invalide. Il ne peut contenir que des lettre ou "_".';
$GLOBALS['__l10n']['Error, check your parameters.'] = 'Erreur, vérifiez vos paramètres.';
$GLOBALS['__l10n']['Server address'] = 'Adresse du serveur';
$GLOBALS['__l10n']['User ID'] = 'Nom d\'utilisateur';
$GLOBALS['__l10n']['Password'] = 'Mot de passe';
$GLOBALS['__l10n']['Database name'] = 'Nom de la base';
$GLOBALS['__l10n']['Tables prefix'] = 'Préfixe des tables';
$GLOBALS['__l10n']['Create tables'] = 'Créer les tables';
$GLOBALS['__l10n']['DotClear seems to be present on your site. You may want to upgrade.'] = 'DotClear semble être présent sur votre site. Vous souhaitez sans doute le mettre à jour.';
$GLOBALS['__l10n']['Don\'t forget to upload your old dotclear.ini in conf/ directory before upgrade.'] = 'N\'oubliez pas de déposer votre ancien fichier dotclear.ini dans le répertoire conf/ avant de mettre à jour.';
$GLOBALS['__l10n']['Tables creation'] = 'Création des tables';
$GLOBALS['__l10n']['Table %s exists'] = 'La table %s existe';
$GLOBALS['__l10n']['Field %s exists'] = 'Le champ %s existe';
$GLOBALS['__l10n']['Create table %s'] = 'Création de la table %s';
$GLOBALS['__l10n']['Add fulltext key %s'] = 'Ajout de la clé fulltext %s';
$GLOBALS['__l10n']['Creation of first category'] = 'Création de la première catégorie';
$GLOBALS['__l10n']['Unable to create all tables. Please check if the tables don\'t exist yet.'] = 'Impossible de créer toutes les tables. Vérifiez qu\'elles n\'existent pas déjà.';
$GLOBALS['__l10n']['Tables successfully created.'] = 'Tables créées avec succès.';
$GLOBALS['__l10n']['DotClear will run properly even if warnings are issued.'] = 'DotClear fonctionnera normalement même si des avertissements sont affichés.';
$GLOBALS['__l10n']['Creation of first user'] = 'Création du premier utilisateur';
$GLOBALS['__l10n']['You are about to create the first user of your blog. This user will be administrator.'] = 'Vous allez créer le premier utilisateur de votre blogue. Cet utilisateur sera administrateur.';
$GLOBALS['__l10n']['Create user'] = 'Créer l\'utilisateur';
$GLOBALS['__l10n']['User succesfuly created'] = 'Utilisateur créé avec succès';
$GLOBALS['__l10n']['Blog configuration'] = 'Configuration du weblogue';
$GLOBALS['__l10n']['DotClear needs to know in which directory it has been installed. For example, if DotClear has been installed in %s/dotclear, then please type "/dotclear" in the field below:'] = 'Il est nécessaire d\'indiquer à DotClear dans quel répertoire il a été installé. Par exemple, si DotClear est installé dans %s/dotclear, veuillez indiquer "/dotclear" dans le champs ci-dessous :';
$GLOBALS['__l10n']['DotClear location'] = 'Emplacement de DotClear';
$GLOBALS['__l10n']['Your blog\'s name'] = 'Nom de votre weblogue';
$GLOBALS['__l10n']['My first weblog'] = 'Mon premier weblogue';
$GLOBALS['__l10n']['Your blog archive addresses (permalinks) may be displayed in various formats. The "Query string" URLs will be displayed as "index.php?/2002/04". The "Path info" URLs will be displayed as "index.php/2002/04" (preferred method for search engine optimization). And the "Get" URLs will be displayed as "index.php?d=2002/04" (only for mod_rewrite fans).'] = 'Les adresses de vos archives (liens permanents) peuvent être affichées dans différents formats. Les URLs au format "Query string" seront affichées comme "index.php?/2002/04". Les URLs au format "Path info" seront affichées comme "index.php/2002/04" (méthode conseillée pour une meilleure indexation). Les URLs au format "Get" seront affichées comme "index.php?d=2002/04" (seulement pour les amateurs de mod_rewrite).';
$GLOBALS['__l10n']['Please note that "Path info" type could be broken on some Web hosting configurations.'] = 'Notez que le format "Path info" peut ne pas fonctionne sur tous les hébergements.';
$GLOBALS['__l10n']['URLs format'] = 'Format des URLs';
$GLOBALS['__l10n']['Save'] = 'Enregistrer';
$GLOBALS['__l10n']['Unable to write dotclear.ini'] = 'Impossible d\'écrire dotclear.ini';
$GLOBALS['__l10n']['Weblog succesfully configured'] = 'Weblogue configuré avec succès';
$GLOBALS['__l10n']['End installation'] = 'Terminer l\'installation';
$GLOBALS['__l10n']['End of installation'] = 'Fin de l\'installation';
$GLOBALS['__l10n']['First post'] = 'Premier billet';
$GLOBALS['__l10n']['This is the first post. Please edit it.'] = 'Ceci est le premier billet. Éditez le.';
$GLOBALS['__l10n']['Creation of first entry.'] = 'Création du premier billet.';
$GLOBALS['__l10n']['Creation of first entry failed.'] = 'La création du premier billet a échoué.';
$GLOBALS['__l10n']['Creation of config file.'] = 'Création du fichier de configuration.';
$GLOBALS['__l10n']['Creation of config file failed.'] = 'La création du fichier de configuration a échoué.';
$GLOBALS['__l10n']['An error occured while finishing installation.'] = 'Une erreur s\'est produite en terminant l\'installation.';
$GLOBALS['__l10n']['Congratulations!'] = 'Félicitations !';
$GLOBALS['__l10n']['You successfully installed DotClear. Have fun.'] = 'Vous avez installé DotClear avec succès. Amusez vous bien.';
$GLOBALS['__l10n']['Manage your blog'] = 'Administrer votre weblogue';
$GLOBALS['__l10n']['Upgrade DotClear'] = 'Mise à jour de DotClear';
$GLOBALS['__l10n']['Update URLed titles'] = 'Mise à jour des titres URLisés';
$GLOBALS['__l10n']['Update %s'] = 'Mise à jour de %s';
$GLOBALS['__l10n']['Reord categories'] = 'Réordonnancement des catégories';
$GLOBALS['__l10n']['Reord categories failed'] = 'Réordonnancement des catégories échoué';
$GLOBALS['__l10n']['Update of dotclear.ini'] = 'Mise à jour de dotclear.ini';
$GLOBALS['__l10n']['Update of dotclear.ini failed'] = 'Mise à jour de dotclear.ini échouée';
$GLOBALS['__l10n']['DotClear successfully upgraded.'] = 'DotClear mis à jour avec succès.';
$GLOBALS['__l10n']['Log in'] = 'Connexion';
?>

==> dotclear-1.2.3.zip: dotclear/l10n/fr-utf8/install.lang.php <==
<?php
# ***** BEGIN LICENSE BLOCK *****
# This file is part of DotClear.
# Copyright (c) 2004 Olivier Meunier and contributors. All rights
# reserved.
#
# DotClear is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# DotClear is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with DotClear; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# ***** END LICENSE BLOCK *****
#


#        DOT NOT MODIFY THIS FILE !




$GLOBALS['__l10n']['Installation'] = 'Installation';
$GLOBALS['__l10n']['Welcome on DotClear installation'] = 'Bienvenue sur l\'installeur de DotClear';
$GLOBALS['__l10n']['You are about to install DotClear. Please choose your language and encoding.'] = 'Vous allez installer DotClear. Choisissez votre langue et l\'encodage.';
$GLOBALS['__l10n']['Go'] = 'Continuer';
$GLOBALS['__l10n']['Next step'] = 'Étape suivante';
$GLOBALS['__l10n']['DotClear is still installed.'] = 'DotClear est déjà installé.';
$GLOBALS['__l10n']['Upgrade'] = 'Mettre à jour';
$GLOBALS['__l10n']['Note: You must accept session cookies to use this installer.'] = 'Note : Vous devez accepter les cookies de session pour utiliser cet installeur';
$GLOBALS['__l10n']['Checking your configuration'] = 'Vérification de votre configuration';
$GLOBALS['__l10n']['PHP version and modules'] = 'Version de PHP et modules';
$GLOBALS['__l10n']['PHP version is %s.'] = 'La version de PHP est %s';
$GLOBALS['__l10n']['PHP version is %s. Version 4.1 or better is required.'] = 'La version de PHP est %s. La version 4.1 ou plus est nécessaire.';
$GLOBALS['__l10n']['%s module is present.'] = 'Le module %s est présent.';
$GLOBALS['__l10n']['%s module is not present.'] = 'Le module %s est absent.';
$GLOBALS['__l10n']['Files permissions'] = 'Permissions sur les fichiers';
$GLOBALS['__l10n']['%s is writable.'] = '%s est accessible en écriture.';
$GLOBALS['__l10n']['%s is not writable. Please change its permissions to install.'] = '%s n\'est pas accessible en écriture. Changez ses permission pour installer.';
$GLOBALS['__l10n']['DotClear cannot be installed.'] = 'DotClear ne peut pas être installé.';
$GLOBALS['__l10n']['Your PHP configuration is not valid. Please contact your Web host to solve this problem.'] = 'Votre configuration n\'est pas suffisante. Contactez votre hébergeur pour résoudre ce problème.';
$GLOBALS['__l10n']['Some files or directories are not writable. Please change their permissions to install DotClear.'] = 'Des fichiers ou répertoires ne sont pas accessibles en écritures. Changez leurs permissions pour installer DotClear.';
$GLOBALS['__l10n']['DotClear can be installed on your site.'] = 'DotClear peut être installé sur votre site.';
$GLOBALS['__l10n']['Database parameters'] = 'Paramètres de la base de données';
$GLOBALS['__l10n']['Invalid tables prefix. It can contain only letters or "_".'] = 'Préfixe des tables invalide. Il ne peut contenir que des lettre ou "_".';
$GLOBALS['__l10n']['Error, check your parameters.'] = 'Erreur, vérifiez vos paramètres.';
$GLOBALS['__l10n']['Server address'] = 'Adresse du serveur';
$GLOBALS['__l10n']['User ID'] = 'Nom d\'utilisateur';
$GLOBALS['__l10n']['Password'] = 'Mot de passe';
$GLOBALS['__l10n']['Database name'] = 'Nom de la base';
$GLOBALS['__l10n']['Tables prefix'] = 'Préfixe des tables';
$GLOBALS['__l10n']['Create tables'] = 'Créer les tables';
$GLOBALS['__l10n']['DotClear seems to be present on your site. You may want to upgrade.'] = 'DotClear semble être présent sur votre site. Vous souhaitez sans doute le mettre à jour.';
$GLOBALS['__l10n']['Don\'t forget to upload your old dotclear.ini in conf/ directory before upgrade.'] = 'N\'oubliez pas de déposer votre ancien fichier dotclear.ini dans le répertoire conf/ avant de mettre à jour.';
$GLOBALS['__l10n']['Tables creation'] = 'Création des tables';
$GLOBALS['__l10n']['Table %s exists'] = 'La table %s existe';
$GLOBALS['__l10n']['Field %s exists'] = 'Le champ %s existe';
$GLOBALS['__l10n']['Create table %s'] = 'Création de la table %s';
$GLOBALS['__l10n']['Add fulltext key %s'] = 'Ajout de la clé fulltext %s';
$GLOBALS['__l10n']['Creation of first category'] = 'Création de la première catégorie';
$GLOBALS['__l10n']['Unable to create all tables. Please check if the tables don\'t exist yet.'] = 'Impossible de créer toutes les tables. Vérifiez qu\'elles n\'existent pas déjà.';
$GLOBALS['__l10n']['Tables successfully created.'] = 'Tables créées avec succès.';
$GLOBALS['__l10n']['DotClear will run properly even if warnings are issued.'] = 'DotClear fonctionnera normalement même si des avertissements sont affichés.';
$GLOBALS['__l10n']['Creation of first user'] = 'Création du premier utilisateur';
$GLOBALS['__l10n']['You are about to create the first user of your blog. This user will be administrator.'] = 'Vous allez créer le premier utilisateur de votre blogue. Cet utilisateur sera administrateur.';
$GLOBALS['__l10n']['Create user'] = 'Créer l\'utilisateur';
$GLOBALS['__l10n']['User successfully created'] = 'Utilisateur créé avec succès';
$GLOBALS['__l10n']['Blog configuration'] = 'Configuration du weblogue';
$GLOBALS['__l10n']['DotClear needs to know in which directory it has been installed. For example, if DotClear has been installed in %s/dotclear, then please type "/dotclear" in the field below:'] = 'Il est nécessaire d\'indiquer à DotClear dans quel répertoire il a été installé. Par exemple, si DotClear est installé dans %s/dotclear, veuillez indiquer "/dotclear" dans le champs ci-dessous :';
$GLOBALS['__l10n']['DotClear location'] = 'Emplacement de DotClear';
$GLOBALS['__l10n']['Your blog\'s name'] = 'Nom de votre weblogue';
$GLOBALS['__l10n']['My first weblog'] = 'Mon premier weblogue';
$GLOBALS['__l10n']['Your blog archive addresses (permalinks) may be displayed in various formats. The "Query string" URLs will be displayed as "index.php?/2002/04". The "Path info" URLs will be displayed as "index.php/2002/04" (preferred method for search engine optimization). And the "Get" URLs will be displayed as "index.php?d=2002/04" (only for mod_rewrite fans).'] = 'Les adresses de vos archives (liens permanents) peuvent être affichées dans différents formats. Les URLs au format "Query string" seront affichées comme "index.php?/2002/04". Les URLs au format "Path info" seront affichées comme "index.php/2002/04" (méthode conseillée pour une meilleure indexation). Les URLs au format "Get" seront affichées comme "index.php?d=2002/04" (seulement pour les amateurs de mod_rewrite).';
$GLOBALS['__l10n']['Please note that "Path info" type could be broken on some Web hosting configurations.'] = 'Notez que le format "Path info" peut ne pas fonctionne sur tous les hébergements.';
$GLOBALS['__l10n']['URLs format'] = 'Format des URLs';
$GLOBALS['__l10n']['Save'] = 'Enregistrer';
$GLOBALS['__l10n']['Unable to write dotclear.ini'] = 'Impossible d\'écrire dotclear.ini';
$GLOBALS['__l10n']['Weblog successfully configured'] = 'Weblogue configuré avec succès';
$GLOBALS['__l10n']['End installation'] = 'Terminer l\'installation';
$GLOBALS['__l10n']['End of installation'] = 'Fin de l\'installation';
$GLOBALS['__l10n']['First post'] = 'Premier billet';
$GLOBALS['__l10n']['This is the first post. Please edit it.'] = 'Ceci est le premier billet. Éditez le.';
$GLOBALS['__l10n']['Creation of first entry.'] = 'Création du premier billet.';
$GLOBALS['__l10n']['Creation of first entry failed.'] = 'La création du premier billet a échoué.';
$GLOBALS['__l10n']['Creation of config file.'] = 'Création du fichier de configuration.';
$GLOBALS['__l10n']['Creation of config file failed.'] = 'La création du fichier de configuration a échoué.';
$GLOBALS['__l10n']['An error occured while finishing installation.'] = 'Une erreur s\'est produite en terminant l\'installation.';
$GLOBALS['__l10n']['Congratulations!'] = 'Félicitations !';
$GLOBALS['__l10n']['You successfully installed DotClear. Have fun.'] = 'Vous avez installé DotClear avec succès. Amusez vous bien.';
$GLOBALS['__l10n']['Manage your blog'] = 'Administrer votre weblogue';
$GLOBALS['__l10n']['Upgrade DotClear'] = 'Mise à jour de DotClear';
$GLOBALS['__l10n']['Update URLed titles'] = 'Mise à jour des titres URLisés';
$GLOBALS['__l10n']['Update %s'] = 'Mise à jour de %s';
$GLOBALS['__l10n']['Reord categories'] = 'Réordonnancement des catégories';
$GLOBALS['__l10n']['Reord categories failed'] = 'Réordonnancement des catégories échoué';
$GLOBALS['__l10n']['Update of dotclear.ini'] = 'Mise à jour de dotclear.ini';
$GLOBALS['__l10n']['Update of dotclear.ini failed'] = 'Mise à jour de dotclear.ini échouée';
$GLOBALS['__l10n']['DotClear successfully upgraded.'] = 'DotClear mis à jour avec succès.';
$GLOBALS['__l10n']['Log in'] = 'Connexion';
?>
